@@ -19,7 +19,8 @@ class BLETextSensorNotifyTrigger : public Trigger<std::string>, public BLETextSe
         break;
       }
       case ESP_GATTC_NOTIFY_EVT: {
-        if (param->notify.conn_id != this->sensor_->parent()->conn_id || param->notify.handle != this->sensor_->handle)
+        if (param->notify.conn_id != this->sensor_->parent()->get_conn_id() ||
+            param->notify.handle != this->sensor_->handle)
           break;
         this->trigger(this->sensor_->parse_data(param->notify.value, param->notify.value_len));
       }
