@@ -113,7 +113,11 @@ void RemoteTransmitterComponent::send_internal(uint32_t send_times, uint32_t sen
     this->rmt_temp_.push_back(rmt_item);
   }
 
-  for (uint16_t i = 0; i < send_times; i++) {
+  if ((this->rmt_temp_.data() == nullptr) || this->rmt_temp_.empty()) {
+    ESP_LOGE(TAG, "Empty data");
+    return;
+  }
+  for (uint32_t i = 0; i < send_times; i++) {
     esp_err_t error = rmt_write_items(this->channel_, this->rmt_temp_.data(), this->rmt_temp_.size(), true);
     if (error != ESP_OK) {
       ESP_LOGW(TAG, "rmt_write_items failed: %s", esp_err_to_name(error));
@@ -121,10 +125,8 @@ void RemoteTransmitterComponent::send_internal(uint32_t send_times, uint32_t sen
     } else {
       this->status_clear_warning();
     }
-    if (i + 1 < send_times) {
-      delay(send_wait / 1000UL);
-      delayMicroseconds(send_wait % 1000UL);
-    }
+    if (i + 1 < send_times)
+      delayMicroseconds(send_wait);
   }
 }
 
