@@ -1,6 +1,6 @@
 """Constants used by esphome."""
 
-__version__ = "2022.12.7"
+__version__ = "2023.2.3"
 
 ALLOWED_NAME_CHARS = "abcdefghijklmnopqrstuvwxyz0123456789-_"
 
@@ -12,7 +12,7 @@ TARGET_PLATFORMS = [PLATFORM_ESP32, PLATFORM_ESP8266, PLATFORM_RP2040]
 
 SOURCE_FILE_EXTENSIONS = {".cpp", ".hpp", ".h", ".c", ".tcc", ".ino"}
 HEADER_FILE_EXTENSIONS = {".h", ".hpp", ".tcc"}
-SECRETS_FILES = {"secrets.yaml", "secrets.yml"}
+SECRETS_FILES = ("secrets.yaml", "secrets.yml")
 
 
 CONF_ABOVE = "above"
@@ -26,6 +26,7 @@ CONF_ACTION_ID = "action_id"
 CONF_ACTION_STATE_TOPIC = "action_state_topic"
 CONF_ACTIVE = "active"
 CONF_ACTIVE_POWER = "active_power"
+CONF_ACTUAL_GAIN = "actual_gain"
 CONF_ADDRESS = "address"
 CONF_ADDRESSABLE_LIGHT_ID = "addressable_light_id"
 CONF_ADVANCED = "advanced"
@@ -140,6 +141,7 @@ CONF_CURRENT = "current"
 CONF_CURRENT_OPERATION = "current_operation"
 CONF_CURRENT_RESISTOR = "current_resistor"
 CONF_CURRENT_TEMPERATURE_STATE_TOPIC = "current_temperature_state_topic"
+CONF_CUSTOM = "custom"
 CONF_CUSTOM_FAN_MODE = "custom_fan_mode"
 CONF_CUSTOM_FAN_MODES = "custom_fan_modes"
 CONF_CUSTOM_PRESET = "custom_preset"
@@ -166,6 +168,7 @@ CONF_DEFAULT_TRANSITION_LENGTH = "default_transition_length"
 CONF_DELAY = "delay"
 CONF_DELIMITER = "delimiter"
 CONF_DELTA = "delta"
+CONF_DEST = "dest"
 CONF_DEVICE = "device"
 CONF_DEVICE_CLASS = "device_class"
 CONF_DEVICE_FACTOR = "device_factor"
@@ -175,6 +178,7 @@ CONF_DIO_PIN = "dio_pin"
 CONF_DIR_PIN = "dir_pin"
 CONF_DIRECTION = "direction"
 CONF_DIRECTION_OUTPUT = "direction_output"
+CONF_DISABLE_CRC = "disable_crc"
 CONF_DISABLED_BY_DEFAULT = "disabled_by_default"
 CONF_DISCONNECT_DELAY = "disconnect_delay"
 CONF_DISCOVERY = "discovery"
@@ -217,6 +221,7 @@ CONF_EVENT = "event"
 CONF_EXPIRE_AFTER = "expire_after"
 CONF_EXPORT_ACTIVE_ENERGY = "export_active_energy"
 CONF_EXPORT_REACTIVE_ENERGY = "export_reactive_energy"
+CONF_EXTERNAL_CLOCK_INPUT = "external_clock_input"
 CONF_EXTERNAL_COMPONENTS = "external_components"
 CONF_EXTERNAL_VCC = "external_vcc"
 CONF_FALLING_EDGE = "falling_edge"
@@ -232,6 +237,7 @@ CONF_FAN_MODE_MEDIUM_ACTION = "fan_mode_medium_action"
 CONF_FAN_MODE_MIDDLE_ACTION = "fan_mode_middle_action"
 CONF_FAN_MODE_OFF_ACTION = "fan_mode_off_action"
 CONF_FAN_MODE_ON_ACTION = "fan_mode_on_action"
+CONF_FAN_MODE_QUIET_ACTION = "fan_mode_quiet_action"
 CONF_FAN_MODE_STATE_TOPIC = "fan_mode_state_topic"
 CONF_FAN_ONLY_ACTION = "fan_only_action"
 CONF_FAN_ONLY_ACTION_USES_FAN_MODE_TIMER = "fan_only_action_uses_fan_mode_timer"
@@ -259,6 +265,7 @@ CONF_FRAGMENTATION = "fragmentation"
 CONF_FRAMEWORK = "framework"
 CONF_FREE = "free"
 CONF_FREQUENCY = "frequency"
+CONF_FRIENDLY_NAME = "friendly_name"
 CONF_FROM = "from"
 CONF_FULL_SPECTRUM = "full_spectrum"
 CONF_FULL_UPDATE_EVERY = "full_update_every"
@@ -306,6 +313,7 @@ CONF_ILLUMINANCE = "illuminance"
 CONF_IMPEDANCE = "impedance"
 CONF_IMPORT_ACTIVE_ENERGY = "import_active_energy"
 CONF_IMPORT_REACTIVE_ENERGY = "import_reactive_energy"
+CONF_INC_PIN = "inc_pin"
 CONF_INCLUDE_INTERNAL = "include_internal"
 CONF_INCLUDES = "includes"
 CONF_INDEX = "index"
@@ -462,6 +470,7 @@ CONF_ON_TAG = "on_tag"
 CONF_ON_TAG_REMOVED = "on_tag_removed"
 CONF_ON_TIME = "on_time"
 CONF_ON_TIME_SYNC = "on_time_sync"
+CONF_ON_TIMEOUT = "on_timeout"
 CONF_ON_TOUCH = "on_touch"
 CONF_ON_TURN_OFF = "on_turn_off"
 CONF_ON_TURN_ON = "on_turn_on"
@@ -542,8 +551,10 @@ CONF_POWER_SAVE_MODE = "power_save_mode"
 CONF_POWER_SUPPLY = "power_supply"
 CONF_PRESET = "preset"
 CONF_PRESET_BOOST = "preset_boost"
+CONF_PRESET_COMMAND_TOPIC = "preset_command_topic"
 CONF_PRESET_ECO = "preset_eco"
 CONF_PRESET_SLEEP = "preset_sleep"
+CONF_PRESET_STATE_TOPIC = "preset_state_topic"
 CONF_PRESSURE = "pressure"
 CONF_PRIORITY = "priority"
 CONF_PROJECT = "project"
@@ -741,6 +752,7 @@ CONF_TX_POWER = "tx_power"
 CONF_TYPE = "type"
 CONF_TYPE_ID = "type_id"
 CONF_UART_ID = "uart_id"
+CONF_UD_PIN = "ud_pin"
 CONF_UID = "uid"
 CONF_UNIQUE = "unique"
 CONF_UNIT_OF_MEASUREMENT = "unit_of_measurement"
@@ -855,6 +867,7 @@ UNIT_AMPERE = "A"
 UNIT_BECQUEREL_PER_CUBIC_METER = "Bq/m³"
 UNIT_BYTES = "B"
 UNIT_CELSIUS = "°C"
+UNIT_CENTIMETER = "cm"
 UNIT_COUNT_DECILITRE = "/dL"
 UNIT_COUNTS_PER_CUBIC_METER = "#/m³"
 UNIT_CUBIC_METER = "m³"
@@ -866,6 +879,7 @@ UNIT_EMPTY = ""
 UNIT_G = "G"
 UNIT_HECTOPASCAL = "hPa"
 UNIT_HERTZ = "Hz"
+UNIT_HOUR = "h"
 UNIT_KELVIN = "K"
 UNIT_KILOGRAM = "kg"
 UNIT_KILOMETER = "km"
@@ -953,6 +967,7 @@ DEVICE_CLASS_PM1 = "pm1"
 DEVICE_CLASS_PM10 = "pm10"
 DEVICE_CLASS_PM25 = "pm25"
 DEVICE_CLASS_POWER_FACTOR = "power_factor"
+DEVICE_CLASS_PRECIPITATION = "precipitation"
 DEVICE_CLASS_PRECIPITATION_INTENSITY = "precipitation_intensity"
 DEVICE_CLASS_PRESSURE = "pressure"
 DEVICE_CLASS_REACTIVE_POWER = "reactive_power"
@@ -993,6 +1008,7 @@ KEY_TARGET_PLATFORM = "target_platform"
 KEY_TARGET_FRAMEWORK = "target_framework"
 KEY_FRAMEWORK_VERSION = "framework_version"
 KEY_NAME = "name"
+KEY_VARIANT = "variant"
 
 # Entity categories
 ENTITY_CATEGORY_NONE = ""
